# ================================ dictElements ================================

@doc raw"""
    dictAtomicNumbers
```
Dict{String, Int64} with 102 entries:
  "Pd" => 46
  "Si" => 14
  "C"  => 6
  "P"  => 15
  "Nb" => 41
    ⋮  =>  ⋮

Z = get(dictAtomicNumbers, "Rb", nothing)
  37

listElement(Z; fmt=Info)
  Element: rubidium
    symbol: Rb
    atomic number: Z = 37
    atomic weight (relative atomic mass): 85.468
```
"""
dictAtomicNumbers = Dict(

  "H"  =>   1, "D"  =>   1, "T"  =>  1, "He" =>  2, "Li" =>  3, "Be" =>   4,
  "B"  =>   5, "C"  =>   6, "N"  =>  7, "O"  =>  8, "F"  =>  9, "Ne" =>  10,
  "Na" =>  11, "Mg" =>  12, "Al" => 13, "Si" => 14, "P"  => 15, "S"  =>  16,
  "Cl" =>  17, "Ar" =>  18, "K"  => 19, "Ca" => 20, "Sc" => 21, "Ti" =>  22,
  "V"  =>  23, "Cr" =>  24, "Mn" => 25, "Fe" => 26, "Co" => 27, "Ni" =>  28,
  "Cu" =>  29, "Zn" =>  30, "Ga" => 31, "Ge" => 32, "As" => 33, "Se" =>  34,
  "Br" =>  35, "Kr" =>  36, "Rb" => 37, "Sr" => 38, "Y"  => 39, "Zr" =>  40,
  "Nb" =>  41, "Mo" =>  42, "Tc" => 43, "Ru" => 44, "Rh" => 45, "Pd" =>  46,
  "Ag" =>  47, "Cd" =>  48, "In" => 49, "Sn" => 50, "Sb" => 51, "Te" =>  52,
  "I"  =>  53, "Xe" =>  54, "Cs" => 55, "Ba" => 56, "La" => 57, "Ce" =>  58,
  "Pr" =>  59, "Nd" =>  60, "Pm" => 61, "Sm" => 62, "Eu" => 63, "Gd" =>  64,
  "Tb" =>  65, "Dy" =>  66, "Ho" => 67, "Er" => 68, "Tm" => 69, "Yb" =>  70,
  "Lu" =>  71, "Hf" =>  72, "Ta" => 73, "W"  => 74, "Re" => 75, "Os" =>  76,
  "Ir" =>  77, "Pt" =>  78, "Au" => 79, "Hg" => 80, "Tl" => 81, "Pb" =>  82,
  "Bi" =>  83, "Po" =>  84, "At" => 85, "Rn" => 86, "Fr" => 87, "Ra" =>  88,
  "Ac" =>  89, "Th" =>  90, "Pa" => 91, "U"  => 92, "Np" => 93, "Pu" =>  94,
  "Am" =>  95, "Cm" =>  96, "Bk" => 97, "Cf" => 98, "Es" => 99, "Fm" => 100, 
  "Md" => 101, "No" => 102
)

# ================================ dictElements ================================

@doc raw"""
    dictElements

Source:  Standard atomic weights of the elements 2021 (IUPAC Technical Report)
#### Example:
```
dictElements
  Dict{Int64, Tuple{String, String, Any}} with 102 entries:
    5  => ("boron", "B", 10.81)
    56 => ("barium", "Ba", 137.33)
    35 => ("bromine", "Br", 79.904)
    55 => ("caesium", "Cs", 132.91)
    60 => ("neodymium", "Nd", 144.24)
    30 => ("zinc", "Zn", 65.38)
     ⋮ =>            ⋮

get(dictElements, 37, nothing)
  ("rubidium", "Rb", 85.468)
```
"""
dictElements = Dict(

         1 => ("hydrogen", "H", 1.008),
         2 => ("helium", "He", 4.0026),
         3 => ("lithium", "Li", 6.94),
         4 => ("beryllium", "Be", 9.0122),
         5 => ("boron", "B", 10.81),
         6 => ("carbon", "C", 12.011),
         7 => ("nitrogen", "N", 14.007),
         8 => ("oxygen", "O", 15.999),
         9 => ("fluorine", "F", 18.998),
        10 => ("neon", "Ne", 20.18),
        11 => ("sodium", "Na", 22.99),
        12 => ("magnesium", "Mg", 24.305),
        13 => ("aluminium", "Al", 26.982),
        14 => ("silicon", "Si", 28.085),
        15 => ("phosphorus", "P", 30.974),
        16 => ("sulfur", "S", 32.06),
        17 => ("chlorine", "Cl", 35.45),
        18 => ("argon", "Ar", 39.95),
        19 => ("potassium", "K", 39.098),
        20 => ("calcium", "Ca", 40.078),
        21 => ("scandium", "Sc", 44.956),
        22 => ("titanium", "Ti", 47.867),
        23 => ("vanadium", "V", 50.942),
        24 => ("chromium", "Cr", 51.996),
        25 => ("manganese", "Mn", 54.938),
        26 => ("iron", "Fe", 55.845),
        27 => ("cobalt", "Co", 58.933),
        28 => ("nickel", "Ni", 58.693),
        29 => ("copper", "Cu", 63.546),
        30 => ("zinc", "Zn", 65.38),
        31 => ("gallium", "Ga", 69.723),
        32 => ("germanium", "Ge", 72.63),
        33 => ("arsenic", "As", 74.922),
        34 => ("selenium", "Se", 78.971),
        35 => ("bromine", "Br", 79.904),
        36 => ("krypton", "Kr", 83.798),
        37 => ("rubidium", "Rb", 85.468),
        38 => ("strontium", "Sr", 87.62),
        39 => ("yttrium", "Y", 88.906),
        40 => ("zirconium", "Zr", 91.224),
        41 => ("niobium", "Nb", 92.906),
        42 => ("molybdenum", "Mo", 95.95),
        43 => ("technetium*", "Tc", nothing),
        44 => ("ruthenium", "Ru", 101.07),
        45 => ("rhodium", "Rh", 102.91),
        46 => ("palladium", "Pd", 106.42),
        47 => ("silver", "Ag", 107.87),
        48 => ("cadmium", "Cd", 112.41),
        49 => ("indium", "In", 114.82),
        50 => ("tin", "Sn", 118.71),
        51 => ("antimony", "Sb", 121.76),
        52 => ("tellurium", "Te", 127.6),
        53 => ("iodine", "I", 126.9),
        54 => ("xenon", "Xe", 131.29),
        55 => ("caesium", "Cs", 132.91),
        56 => ("barium", "Ba", 137.33),
        57 => ("lanthanum", "La", 138.91),
        58 => ("cerium", "Ce", 140.12),
        59 => ("praseodymium", "Pr", 140.91),
        60 => ("neodymium", "Nd", 144.24),
        61 => ("promethium*", "Pm", nothing),
        62 => ("samarium", "Sm", 150.36),
        63 => ("europium", "Eu", 151.96),
        64 => ("gadolinium", "Gd", 157.25),
        65 => ("terbium", "Tb", 158.93),
        66 => ("dysprosium", "Dy", 162.5),
        67 => ("holmium", "Ho", 164.93),
        68 => ("erbium", "Er", 167.26),
        69 => ("thulium", "Tm", 168.93),
        70 => ("ytterbium", "Yb", 173.05),
        71 => ("lutetium", "Lu", 174.97),
        72 => ("hafnium", "Hf", 178.49),
        73 => ("tantalum", "Ta", 180.95),
        74 => ("tungsten", "W", 183.84),
        75 => ("rhenium", "Re", 186.21),
        76 => ("osmium", "Os", 190.23),
        77 => ("iridium", "Ir", 192.22),
        78 => ("platinum", "Pt", 195.08),
        79 => ("gold", "Au", 196.97),
        80 => ("mercury", "Hg", 200.59),
        81 => ("thallium", "Tl", 204.38),
        82 => ("lead", "Pb", 207.2),
        83 => ("bismuth*", "Bi", 208.98),
        84 => ("polonium*", "Po", nothing),
        85 => ("astatine*", "At", nothing),
        86 => ("radon*", "Rn", nothing),
        87 => ("francium*", "Fr", nothing),
        88 => ("radium*", "Ra", nothing),
        89 => ("actinium*", "Ac", nothing),
        90 => ("thorium*", "Th", 232.04),
        91 => ("protactinium*", "Pa", 231.04),
        92 => ("uranium*", "U", 238.03),
        93 => ("neptunium*", "Np", nothing),
        94 => ("plutonium*", "Pu", nothing),
        95 => ("americium*", "Am", nothing),
        96 => ("curium*", "Cm", nothing),
        97 => ("berkelium*", "Bk", nothing),
        98 => ("californium*", "Cf", nothing),
        99 => ("einsteinium*", "Es", nothing),
       100 => ("fermium*", "Fm", nothing),
       101 => ("mendelevium*", "Md", nothing),
       102 => ("nobelium*", "No", nothing)

       )


# ======================== dictIsotopes ========================================

@doc raw"""
    dictIsotopes

Sources: AME2020, LINDC(NDS)-0794 and INDC(NDS)-0833
#### Example:
```
dictIsotopes
  Dict{Tuple{Int64, Int64}, Tuple{String, String, Int64, Int64, Int64, Float64, Float64, Real, Int64, Float64, Float64, Any, Any}} with 341 entries:
    (71, 175) => ("¹⁷⁵Lu", "lutetium", 71, 175, 104, 5.37, 174.941, 7//2, 1, 1.0e…
    (40, 92)  => ("⁹²Zr", "zirconium", 40, 92, 52, 4.3057, 91.905, 0, 1, 1.0e100,…
    (48, 111) => ("¹¹¹Cd", "cadmium", 48, 111, 63, 4.5845, 110.904, 1//2, 1, 1.0e…
    (72, 176) => ("¹⁷⁶Hf", "hafnium", 72, 176, 104, 5.3286, 175.941, 0, 1, 1.0e10…
    (30, 68)  => ("⁶⁸Zn", "zinc", 30, 68, 38, 3.9658, 67.9248, 0, 1, 1.0e100, 0.0…
    (76, 184) => ("¹⁸⁴Os", "osmium", 76, 184, 108, 5.3823, 183.952, 0, 1, 5.6e13,…
    (54, 129) => ("¹²⁹Xe", "xenon", 54, 129, 75, 4.7775, 128.905, 1//2, 1, 1.0e10…
        ⋮     =>                                ⋮

get(dictIsotopes, (37,87), nothing)
  ("⁸⁷Rb", "rubidium", 37, 87, 50, 4.1989, 86.90918053, 3//2, -1, 4.97e10, 2.75129, 0.1335, 27.83)
```
"""
dictIsotopes = Dict(

       (0, 1) => ("n"    , "neutron"  ,   0,   1,   1,    0.0,   1.008664916, 1//2, 1, 0.0000194, -1.9130427, 0.0, nothing),
       (1, 1) => ("¹H"   , "hydrogen" ,   1,   1,   0, 0.8783,   1.007825032, 1//2, 1, 1.0e100, 2.792847351, 0.0, 99.9855),
       (1, 2) => ("²D"   , "deuterium",   1,   2,   1, 2.1421,   2.014101778, 1, 1, 1.0e100, 0.857438231, 0.0028578, 0.0145),
       (1, 3) => ("³T"   , "tritium"  ,   1,   3,   2, 1.7591,   3.016049281, 1//2, 1, 12.33, 2.97896246, 0.0, nothing),
       (2, 3) => ("³He"  , "helium"   ,   2,   3,   1, 1.9661,   3.016029322, 1//2, 1, 1.0e100, -2.12762531, 0.0, 0.0002),
       (2, 4) => ("⁴He"  , "helium"   ,   2,   4,   2, 1.6755,   4.002603254, 0, 1, 1.0e100, 0.0, 0.0, 99.9998),
       (3, 6) => ("⁶Li"  , "lithium"  ,   3,   6,   3, 2.589,    6.015122887, 1, 1, 1.0e100, 0.822043, -0.000806, 4.85),
       (3, 7) => ("⁷Li"  , "lithium"  ,   3,   7,   4, 2.444,    7.016003434, 3//2, -1, 1.0e100, 3.256407, -0.04, 95.15),
       (4, 9) => ("⁹Be"  , "beryllium",   4,   9,   5, 2.519,    9.012183062, 3//2, -1, 1.0e100, -1.17743, 0.0529, 100.0),
      (4, 10) => ("¹⁰Be" , "beryllium",   4,  10,   6, 2.355,   10.01353469, 0, 1, 1.51e6, 0.0, 0.0, nothing),
      (5, 10) => ("¹⁰B"  , "boron"    ,   5,  10,   5, 2.4277,  10.01293686, 3, 1, 1.0e100, 1.8004636, 0.0846, 19.65),
      (5, 11) => ("¹¹B"  , "boron"    ,   5,  11,   6, 2.406,   11.00930517, 3//2, -1, 1.0e100, 2.688378, 0.04059, 80.35),
      (6, 12) => ("¹²C"  , "carbon"   ,   6,  12,   6, 2.4702,  12.0,        0, 1, 1.0e100, 0.0, 0.0, 98.94),
      (6, 13) => ("¹³C"  , "carbon"   ,   6,  13,   7, 2.4614,  13.00335484, 1//2, -1, 1.0e100, 0.702369, 0.0, 1.06),
      (6, 14) => ("¹⁴C"  , "carbon"   ,   6,  14,   8, 2.5025,  14.00324199, 0, 1, 5700.0, 0.0, 0.0, nothing),
      (7, 14) => ("¹⁴N"  , "nitrogen" ,   7,  14,   7, 2.5582,  14.00307400, 1, 1, 1.0e100, 0.403573, 0.02044, 99.6205),
      (7, 15) => ("¹⁵N"  , "nitrogen" ,   7,  15,   8, 2.6058,  15.00010890, 1//2, -1, 1.0e100, -0.2830569, 0.0, 0.3795),
      (8, 16) => ("¹⁶O"  , "oxygen"   ,   8,  16,   8, 2.6991,  15.99491462, 0, 1, 1.0e100, 0.0, 0.0, 99.757),
      (8, 17) => ("¹⁷O"  , "oxygen"   ,   8,  17,   9, 2.6932,  16.99913176, 5//2, 1, 1.0e100, -1.893543, -0.0256, 0.03835),
      (8, 18) => ("¹⁸O"  , "oxygen"   ,   8,  18,  10, 2.7726,  17.99915961, 0, 1, 1.0e100, 0.0, 0.0, 0.2045),
      (9, 19) => ("¹⁹F"  , "fluorine" ,   9,  19,  10, 2.8976,  18.99840316, 1//2, 1, 1.0e100, 2.628321, 0.0, 100.0),
     (10, 20) => ("²⁰Ne" , "neon"     ,  10,  20,  10, 3.0055,  19.99244018, 0, 1, 1.0e100, 0.0, 0.0, 90.48),
     (10, 21) => ("²¹Ne" , "neon"     ,  10,  21,  11, 2.9695,  20.99384669, 3//2, 1, 1.0e100, -0.6617, 0.1016, 0.27),
     (10, 22) => ("²²Ne" , "neon"     ,  10,  22,  12, 2.9525,  21.99138511, 0, 1, 1.0e100, 0.0, 0.0, 9.25),
     (11, 22) => ("²²Na" , "sodium"   ,  11,  22,  11, 2.9852,  21.99443755, 3, 1, 2.6, 1.746, 0.18, nothing),
     (11, 23) => ("²³Na" , "sodium"   ,  11,  23,  12, 2.9936,  22.98976928, 3//2, 1, 1.0e100, 2.2175, 0.104, 100.0),
     (12, 24) => ("²⁴Mg" , "magnesium",  12,  24,  12, 3.057,   23.98504169, 0, 1, 1.0e100, 0.0, 0.0, 78.965),
     (12, 25) => ("²⁵Mg" , "magnesium",  12,  25,  13, 3.0284,  24.98583697, 5//2, 1, 1.0e100, -0.85533, 0.199, 10.011),
     (12, 26) => ("²⁶Mg" , "magnesium",  12,  26,  14, 3.0337,  25.98259297, 0, 1, 1.0e100, 0.0, 0.0, 11.025),
     (13, 26) => ("²⁶Al" , "aluminium",  13,  26,  13, 3.05,    25.98689188, 5, 1, 717000.0, 2.803, 0.26, nothing),
     (13, 27) => ("²⁷Al" , "aluminium",  13,  27,  14, 3.061,   26.98153841, 5//2, 1, 1.0e100, 3.6407, 0.1466, 100.0),
     (14, 28) => ("²⁸Si" , "silicon"  ,  14,  28,  14, 3.1224,  27.97692653, 0, 1, 1.0e100, 0.0, 0.0, 92.2545),
     (14, 29) => ("²⁹Si" , "silicon"  ,  14,  29,  15, 3.1176,  28.97649466, 1//2, 1, 1.0e100, -0.555052, 0.0, 4.672),
     (14, 30) => ("³⁰Si" , "silicon"  ,  14,  30,  16, 3.1336,  29.97377014, 0, 1, 1.0e100, 0.0, 0.0, 3.0735),
     (15, 31) => ("³¹P"  , "phosphorus", 15,  31,  16, 3.1889,  30.97376200, 1//2, 1, 1.0e100, 1.130925, 0.0, 100.0),
     (16, 32) => ("³²S"  , "sulfur",     16,  32,  16, 3.2611,  31.97207117, 0, 1, 1.0e100, 0.0, 0.0, 94.85),
     (16, 33) => ("³³S"  , "sulfur",     16,  33,  17, 3.3,     32.97145891, 3//2, 1, 1.0e100, 0.64325, -0.0678, 0.763),
     (16, 34) => ("³⁴S"  , "sulfur",     16,  34,  18, 3.2847,  33.96786701, 0, 1, 1.0e100, 0.0, 0.0, 4.365),
     (16, 36) => ("³⁶S"  , "sulfur",     16,  36,  20, 3.2985,  35.96708069, 0, 1, 1.0e100, 0.0, 0.0, 0.0158),
     (17, 35) => ("³⁵Cl" , "chlorine",   17,  35,  18, 3.3654,  34.96885269, 3//2, 1, 1.0e100, 0.8217, -0.817, 75.8),
     (17, 36) => ("³⁶Cl" , "chlorine",   17,  36,  19, 3.37,    35.96830682, 2, 1, 301000.0, 1.2849, -0.178, nothing),
     (17, 37) => ("³⁷Cl" , "chlorine",   17,  37,  20, 3.384,   36.96590257, 3//2, 1, 1.0e100, 0.684, -0.0644, 24.2),
     (18, 36) => ("³⁶Ar" , "argon",      18,  36,  18, 3.3905,  35.96754511, 0, 1, 1.0e100, 0.0, 0.0, 0.3336),
     (18, 38) => ("³⁸Ar" , "argon",      18,  38,  20, 3.4028,  37.96273210, 0, 1, 1.0e100, 0.0, 0.0, 0.0629),
     (18, 39) => ("³⁹Ar" , "argon",      18,  39,  21, 3.4093,  38.96431304, 7//2, -1, 269.0, -1.59, -0.116, nothing),
     (18, 40) => ("⁴⁰Ar" , "argon",      18,  40,  22, 3.4274,  39.96238312, 0, 1, 1.0e100, 0.0, 0.0, 99.6035),
     (19, 39) => ("³⁹K"  , "potassium",  19,  39,  20, 3.4349,  38.96370648, 3//2, 1, 1.0e100, 0.39147, 0.0603, 93.2581),
     (19, 40) => ("⁴⁰K"  , "potassium",  19,  40,  21, 3.4381,  39.96399817, 4, -1, 1.25e9, -1.29797, -0.075, 0.0117),
     (19, 41) => ("⁴¹K"  , "potassium",  19,  41,  22, 3.4518,  40.96182526, 3//2, 1, 1.0e100, 0.21482, -0.0734, 6.7302),
     (20, 40) => ("⁴⁰Ca" , "calcium",    20,  40,  20, 3.4776,  39.96259085, 0, 1, 1.0e100, 0.0, 0.0, 96.941),
     (20, 41) => ("⁴¹Ca" , "calcium",    20,  41,  21, 3.478,   40.96227791, 7//2, -1, 100000.0, -1.5942, -0.665, nothing),
     (20, 42) => ("⁴²Ca" , "calcium",    20,  42,  22, 3.5081,  41.95861778, 0, 1, 1.0e100, 0.0, 0.0, 0.647),
     (20, 43) => ("⁴³Ca" , "calcium",    20,  43,  23, 3.4954,  42.95876638, 7//2, -1, 1.0e100, -1.31733, -0.0408, 0.135),
     (20, 44) => ("⁴⁴Ca" , "calcium",    20,  44,  24, 3.5179,  43.95548149, 0, 1, 1.0e100, 0.0, 0.0, 2.086),
     (20, 46) => ("⁴⁶Ca" , "calcium",    20,  46,  26, 3.4953,  45.95368773, 0, 1, 1.0e100, 0.0, 0.0, 0.004),
     (20, 48) => ("⁴⁸Ca" , "calcium",    20,  48,  28, 3.4771,  47.95252265, 0, 1, 2.9e19, 0.0, 0.0, 0.187),
     (21, 45) => ("⁴⁵Sc" , "scandium",   21,  45,  24, 3.5459,  44.95590705, 7//2, -1, 4.0e19, 4.754, -0.22, 100.0),
     (22, 46) => ("⁴⁶Ti" , "titanium",   22,  46,  24, 3.607,   45.95262636, 0, 1, 1.0e100, 0.0, 0.0, 8.25),
     (22, 47) => ("⁴⁷Ti" , "titanium",   22,  47,  25, 3.5962,  46.95175749, 5//2, -1, 1.0e100, -0.78848, 0.302, 7.44),
     (22, 48) => ("⁴⁸Ti" , "titanium",   22,  48,  26, 3.5921,  47.94794068, 0, 1, 1.0e100, 0.0, 0.0, 73.72),
     (22, 49) => ("⁴⁹Ti" , "titanium",   22,  49,  27, 3.5733,  48.94786439, 7//2, -1, 1.0e100, -1.10417, 0.247, 5.41),
     (22, 50) => ("⁵⁰Ti" , "titanium",   22,  50,  28, 3.5704,  49.94478562, 0, 1, 1.0e100, 0.0, 0.0, 5.18),
     (23, 50) => ("⁵⁰V"  ,  "vanadium",  23,  50,  27, 3.58,    49.94715668, 6, 1, 2.65e17, 3.3456889, 0.21, 0.25),
     (23, 51) => ("⁵¹V"  , "vanadium",   23,  51,  28, 3.6002,  50.94395766, 7//2, -1, 1.0e100, 5.1464, -0.52, 99.75),
     (24, 50) => ("⁵⁰Cr" , "chromium",   24,  50,  26, 3.6588,  49.94604221, 0, 1, 1.3e18, 0.0, 0.0, 4.345),
     (24, 52) => ("⁵²Cr" , "chromium",   24,  52,  28, 3.6452,  51.94050471, 0, 1, 1.0e100, 0.0, 0.0, 83.789),
     (24, 53) => ("⁵³Cr" , "chromium",   24,  53,  29, 3.6511,  52.94064630, 3//2, -1, 1.0e100, -0.47431, -0.15, 9.501),
     (24, 54) => ("⁵⁴Cr" , "chromium",   24,  54,  30, 3.6885,  53.93887736, 0, 1, 1.0e100, 0.0, 0.0, 2.365),
     (25, 53) => ("⁵³Mn" , "manganese",  25,  53,  28, 3.6662,  52.94128750, 7//2, -1, 3.7e6, 5.033, 0.17, nothing),
     (25, 55) => ("⁵⁵Mn" , "manganese",  25,  55,  30, 3.7057,  54.93804304, 5//2, -1, 1.0e100, 3.4669, 0.33, 100.0),
     (26, 54) => ("⁵⁴Fe" , "iron",       26,  54,  28, 3.6933,  53.93960819, 0, 1, 1.0e100, 0.0, 0.0, 5.845),
     (26, 56) => ("⁵⁶Fe" , "iron",       26,  56,  30, 3.7377,  55.93493554, 0, 1, 1.0e100, 0.0, 0.0, 91.754),
     (26, 57) => ("⁵⁷Fe" , "iron",       26,  57,  31, 3.7532,  56.93539195, 1//2, -1, 1.0e100, 0.09064, 0.0, 2.119),
     (26, 58) => ("⁵⁸Fe" , "iron",       26,  58,  32, 3.7745,  57.93327358, 0, 1, 1.0e100, 0.0, 0.0, 0.282),
     (26, 60) => ("⁶⁰Fe" , "iron",       26,  60,  34, 3.78,    59.93407025, 0, 1, 2.62e6, 0.0, 0.0, nothing),
     (27, 59) => ("⁵⁹Co" , "cobalt",     27,  59,  32, 3.7875,  58.93319352, 7//2, -1, 1.0e100, 4.615, 0.42, 100.0),
     (27, 60) => ("⁶⁰Co" , "cobalt",     27,  60,  33, 3.79,    59.93381554, 5, 1, 1925.28, 3.799, 0.46, nothing),
     (28, 58) => ("⁵⁸Ni" , "nickel",     28,  58,  30, 3.7757,  57.93534165, 0, 1, 1.0e100, 0.0, 0.0, 68.0769),
     (28, 60) => ("⁶⁰Ni" , "nickel",     28,  60,  32, 3.8118,  59.93078513, 0, 1, 1.0e100, 0.0, 0.0, 26.2231),
     (28, 61) => ("⁶¹Ni" , "nickel",     28,  61,  33, 3.8225,  60.93105482, 3//2, -1, 1.0e100, -0.74965, 0.162, 1.1399),
     (28, 62) => ("⁶²Ni" , "nickel",     28,  62,  34, 3.8399,  61.92834475, 0, 1, 1.0e100, 0.0, 0.0, 3.6345),
     (28, 64) => ("⁶⁴Ni" , "nickel",     28,  64,  36, 3.8572,  63.92796623, 0, 1, 1.0e100, 0.0, 0.0, 0.9256),
     (29, 63) => ("⁶³Cu" , "copper",     29,  63,  34, 3.8823,  62.92959712, 3//2, -1, 1.0e100, 2.2259, -0.22, 69.15),
     (29, 65) => ("⁶⁵Cu" , "copper",     29,  65,  36, 3.9022,  64.92778948, 3//2, -1, 1.0e100, 2.3844, -0.204, 30.85),
     (30, 64) => ("⁶⁴Zn" , "zinc",       30,  64,  34, 3.9283,  63.92914178, 0, 1, 1.0e100, 0.0, 0.0, 49.17),
     (30, 66) => ("⁶⁶Zn" , "zinc",       30,  66,  36, 3.9491,  65.92603364, 0, 1, 1.0e100, 0.0, 0.0, 27.73),
     (30, 67) => ("⁶⁷Zn" , "zinc",       30,  67,  37, 3.953,   66.92712742, 5//2, -1, 1.0e100, 0.87485, 0.122, 4.04),
     (30, 68) => ("⁶⁸Zn" , "zinc",       30,  68,  38, 3.9658,  67.92484423, 0, 1, 1.0e100, 0.0, 0.0, 18.45),
     (30, 70) => ("⁷⁰Zn" , "zinc",       30,  70,  40, 3.9845,  69.92531918, 0, 1, 3.8e18, 0.0, 0.0, 0.61),
     (31, 69) => ("⁶⁹Ga" , "gallium",    31,  69,  38, 3.9973,  68.92557353, 3//2, -1, 1.0e100, 2.01502, 0.171, 60.108),
     (31, 71) => ("⁷¹Ga" , "gallium",    31,  71,  40, 4.0118,  70.92470255, 3//2, -1, 1.0e100, 2.56033, 0.107, 39.892),
     (32, 70) => ("⁷⁰Ge" , "germanium",  32,  70,  38, 4.0414,  69.92424854, 0, 1, 1.0e100, 0.0, 0.0, 20.52),
     (32, 72) => ("⁷²Ge" , "germanium",  32,  72,  40, 4.0576,  71.92207582, 0, 1, 1.0e100, 0.0, 0.0, 27.45),
     (32, 73) => ("⁷³Ge" , "germanium",  32,  73,  41, 4.0632,  72.92345895, 9//2, 1, 1.0e100, -0.87824, -0.196, 7.76),
     (32, 74) => ("⁷⁴Ge" , "germanium",  32,  74,  42, 4.0742,  73.92117776, 0, 1, 1.0e100, 0.0, 0.0, 36.52),
     (32, 76) => ("⁷⁶Ge" , "germanium",  32,  76,  44, 4.0811,  75.92140273, 0, 1, 1.0e100, 0.0, 0.0, 7.75),
     (33, 75) => ("⁷⁵As" , "arsenic",    33,  75,  42, 4.0968,  74.92159456, 3//2, -1, 1.0e100, 1.4383, 0.311, 100.0),
     (34, 74) => ("⁷⁴Se" , "selenium",   34,  74,  40, 4.07,    73.92247593, 0, 1, 1.0e100, 0.0, 0.0, 0.86),
     (34, 76) => ("⁷⁶Se" , "selenium",   34,  76,  42, 4.1395,  75.91921370, 0, 1, 1.0e100, 0.0, 0.0, 9.23),
     (34, 77) => ("⁷⁷Se" , "selenium",   34,  77,  43, 4.1395,  76.91991415, 1//2, -1, 1.0e100, 0.53356, 0.0, 7.6),
     (34, 78) => ("⁷⁸Se" , "selenium",   34,  78,  44, 4.1406,  77.91730924, 0, 1, 1.0e100, 0.0, 0.0, 23.69),
     (34, 79) => ("⁷⁹Se" , "selenium",   34,  79,  45, 4.14,    78.91849925, 7//2, 1, 327000.0, -1.018, nothing, nothing),
     (34, 80) => ("⁸⁰Se" , "selenium",   34,  80,  46, 4.14,    79.91652176, 0, 1, 1.0e100, 0.0, 0.0, 49.8),
     (35, 79) => ("⁷⁹Br" , "bromine",    35,  79,  44, 4.1629,  78.91833757, 3//2, -1, 1.0e100, 2.1046, 0.3087, 50.65),
     (35, 81) => ("⁸¹Br" , "bromine",    35,  81,  46, 4.1599,  80.91628820, 3//2, -1, 1.0e100, 2.2686, 0.2579, 49.35),
     (36, 78) => ("⁷⁸Kr" , "krypton",    36,  78,  42, 4.2038,  77.92036634, 0, 1, 1.0e100, 0.0, 0.0, 0.355),
     (36, 80) => ("⁸⁰Kr" , "krypton",    36,  80,  44, 4.197,   79.91637794, 0, 1, 1.0e100, 0.0, 0.0, 2.286),
     (36, 81) => ("⁸¹Kr" , "krypton",    36,  81,  45, 4.1952,  80.91658970, 7//2, 1, 229000.0, -0.907, 0.644, nothing),
     (36, 82) => ("⁸²Kr" , "krypton",    36,  82,  46, 4.1919,  81.91348115, 0, 1, 1.0e100, 0.0, 0.0, 11.593),
     (36, 83) => ("⁸³Kr" , "krypton",    36,  83,  47, 4.1871,  82.91412652, 9//2, 1, 1.0e100, -0.97073, 0.259, 11.5),
     (36, 84) => ("⁸⁴Kr" , "krypton",    36,  84,  48, 4.1884,  83.91149773, 0, 1, 1.0e100, 0.0, 0.0, 56.987),
     (36, 85) => ("⁸⁵Kr" , "krypton",    36,  85,  49, 4.1846,  84.91252726, 9//2, 1, 10.74, -1.0055, 0.433, nothing),
     (36, 86) => ("⁸⁶Kr" , "krypton",    36,  86,  50, 4.1835,  85.91061062, 0, 1, 1.0e100, 0.0, 0.0, 17.279),
     (37, 85) => ("⁸⁵Rb" , "rubidium",   37,  85,  48, 4.2036,  84.91178974, 5//2, -1, 1.0e100, 1.35306, 0.276, 72.17),
     (37, 87) => ("⁸⁷Rb" , "rubidium",   37,  87,  50, 4.1989,  86.90918053, 3//2, -1, 4.97e10, 2.75129, 0.1335, 27.83),
     (38, 84) => ("⁸⁴Sr" , "strontium",  38,  84,  46, 4.2394,  83.91341912, 0, 1, 1.0e100, 0.0, 0.0, 0.56),
     (38, 86) => ("⁸⁶Sr" , "strontium",  38,  86,  48, 4.2307,  85.90926072, 0, 1, 1.0e100, 0.0, 0.0, 9.86),
     (38, 87) => ("⁸⁷Sr" , "strontium",  38,  87,  49, 4.2249,  86.90887749, 9//2, 1, 1.0e100, -1.09316, 0.305, 7.0),
     (38, 88) => ("⁸⁸Sr" , "strontium",  38,  88,  50, 4.224,   87.90561225, 0, 1, 1.0e100, 0.0, 0.0, 82.58),
     (39, 89) => ("⁸⁹Y"  , "yttrium",    39,  89,  50, 4.243,   88.90583816, 1//2, -1, 1.0e100, -0.137298, 0.0, 100.0),
     (40, 90) => ("⁹⁰Zr" , "zirconium",  40,  90,  50, 4.2694,  89.90469876, 0, 1, 1.0e100, 0.0, 0.0, 51.45),
     (40, 91) => ("⁹¹Zr" , "zirconium",  40,  91,  51, 4.2845,  90.90564021, 5//2, 1, 1.0e100, -1.3022, -0.176, 11.22),
     (40, 92) => ("⁹²Zr" , "zirconium",  40,  92,  52, 4.3057,  91.90503534, 0, 1, 1.0e100, 0.0, 0.0, 17.15),
     (40, 94) => ("⁹⁴Zr" , "zirconium",  40,  94,  54, 4.332,   93.90631252, 0, 1, 1.0e100, 0.0, 0.0, 17.38),
     (40, 96) => ("⁹⁶Zr" , "zirconium",  40,  96,  56, 4.3512,  95.90827762, 0, 1, 2.0e19, 0.0, 0.0, 2.8),
     (41, 91) => ("⁹¹Nb" , "niobium",    41,  91,  50, 4.28,    90.90699026, 9//2, 1, 680.0, 6.513, -0.25, nothing),
     (41, 92) => ("⁹²Nb" , "niobium",    41,  92,  51, 4.3026,  91.90718858, 7, 1, 3.47e7, 5.13, -0.35, nothing),
     (41, 93) => ("⁹³Nb" , "niobium",    41,  93,  52, 4.324,   92.90637317, 9//2, 1, 1.0e100, 6.163, -0.32, 100.0),
     (42, 92) => ("⁹²Mo" , "molybdenum", 42,  92,  50, 4.3151,  91.90680715, 0, 1, 1.0e100, 0.0, 0.0, 14.649),
     (42, 94) => ("⁹⁴Mo" , "molybdenum", 42,  94,  52, 4.3529,  93.90508359, 0, 1, 1.0e100, 0.0, 0.0, 9.187),
     (42, 95) => ("⁹⁵Mo" , "molybdenum", 42,  95,  53, 4.3628,  94.90583744, 5//2, 1, 1.0e100, -0.9132, -0.022, 15.873),
     (42, 96) => ("⁹⁶Mo" , "molybdenum", 42,  96,  54, 4.3847,  95.90467477, 0, 1, 1.0e100, 0.0, 0.0, 16.673),
     (42, 97) => ("⁹⁷Mo" , "molybdenum", 42,  97,  55, 4.388,   96.90601690, 5//2, 1, 1.0e100, -0.9324, 0.255, 9.582),
     (42, 98) => ("⁹⁸Mo" , "molybdenum", 42,  98,  56, 4.4091,  97.90540361, 0, 1, 1.0e100, 0.0, 0.0, 24.292),
    (42, 100) => ("¹⁰⁰Mo", "molybdenum", 42, 100,  58, 4.4468,  99.90746798, 0, 1, 7.01e18, 0.0, 0.0, 9.744),
     (43, 99) => ("⁹⁹Tc" , "technetium", 43,  99,  56, 4.4,     98.90624968, 9//2, 1, 211000.0, 5.678, -0.129, nothing),
     (44, 96) => ("⁹⁶Ru" , "ruthenium",  44,  96,  52, 4.3908,  95.90758891, 0, 1, 1.0e100, 0.0, 0.0, 5.54),
     (44, 98) => ("⁹⁸Ru" , "ruthenium",  44,  98,  54, 4.4229,  97.90528671, 0, 1, 1.0e100, 0.0, 0.0, 1.87),
     (44, 99) => ("⁹⁹Ru" , "ruthenium",  44,  99,  55, 4.4338,  98.90593028, 5//2, 1, 1.0e100, -0.641, 0.079, 12.76),
    (44, 100) => ("¹⁰⁰Ru", "ruthenium",  44, 100,  56, 4.4531,  99.90421046, 0, 1, 1.0e100, 0.0, 0.0, 12.6),
    (44, 101) => ("¹⁰¹Ru", "ruthenium",  44, 101,  57, 4.4606, 100.9055731, 5//2, 1, 1.0e100, -0.718, 0.46, 17.06),
    (44, 102) => ("¹⁰²Ru", "ruthenium",  44, 102,  58, 4.4809, 101.9043403, 0, 1, 1.0e100, 0.0, 0.0, 31.55),
    (44, 104) => ("¹⁰⁴Ru", "ruthenium",  44, 104,  60, 4.5098, 103.9054253, 0, 1, 1.0e100, 0.0, 0.0, 18.62),
    (45, 103) => ("¹⁰³Rh", "rhodium",    45, 103,  58, 4.4945, 102.9054941, 1//2, -1, 1.0e100, -0.08829, 0.0, 100.0),
    (46, 102) => ("¹⁰²Pd", "palladium",  46, 102,  56, 4.4827, 101.9056323, 0, 1, 1.0e100, 0.0, 0.0, 1.02),
    (46, 104) => ("¹⁰⁴Pd", "palladium",  46, 104,  58, 4.5078, 103.9040304, 0, 1, 1.0e100, 0.0, 0.0, 11.14),
    (46, 105) => ("¹⁰⁵Pd", "palladium",  46, 105,  59, 4.515,  104.9050795, 5//2, 1, 1.0e100, -0.642, 0.66, 22.33),
    (46, 106) => ("¹⁰⁶Pd", "palladium",  46, 106,  60, 4.5318, 105.9034803, 0, 1, 1.0e100, 0.0, 0.0, 27.33),
    (46, 108) => ("¹⁰⁸Pd", "palladium",  46, 108,  62, 4.5563, 107.9038918, 0, 1, 1.0e100, 0.0, 0.0, 26.46),
    (46, 110) => ("¹¹⁰Pd", "palladium",  46, 110,  64, 4.5782, 109.9051729, 0, 1, 1.0e100, 0.0, 0.0, 11.72),
    (47, 107) => ("¹⁰⁷Ag", "silver",     47, 107,  60, 4.5454, 106.9050915, 1//2, -1, 1.0e100, -0.11352, 0.0, 51.839),
    (47, 109) => ("¹⁰⁹Ag", "silver",     47, 109,  62, 4.5638, 108.9047558, 1//2, -1, 1.0e100, 0.13051, 0.0, 48.161),
    (48, 106) => ("¹⁰⁶Cd", "cadmium",    48, 106,  58, 4.5383, 105.9064598, 0, 1, 1.0e100, 0.0, 0.0, 1.245),
    (48, 108) => ("¹⁰⁸Cd", "cadmium",    48, 108,  60, 4.5577, 107.9041836, 0, 1, 1.0e100, 0.0, 0.0, 0.888),
    (48, 110) => ("¹¹⁰Cd", "cadmium",    48, 110,  62, 4.5765, 109.9030075, 0, 1, 1.0e100, 0.0, 0.0, 12.47),
    (48, 111) => ("¹¹¹Cd", "cadmium",    48, 111,  63, 4.5845, 110.9041838, 1//2, 1, 1.0e100, -0.594, 0.0, 12.795),
    (48, 112) => ("¹¹²Cd", "cadmium",    48, 112,  64, 4.5944, 111.9027639, 0, 1, 1.0e100, 0.0, 0.0, 24.109),
    (48, 113) => ("¹¹³Cd", "cadmium",    48, 113,  65, 4.6012, 112.9044081, 1//2, 1, 8.04e15, -0.6213, 0.0, 12.227),
    (48, 114) => ("¹¹⁴Cd", "cadmium",    48, 114,  66, 4.6087, 113.9033650, 0, 1, 1.0e100, 0.0, 0.0, 28.754),
    (48, 116) => ("¹¹⁶Cd", "cadmium",    48, 116,  68, 4.6203, 115.9047632, 0, 1, 3.3e19, 0.0, 0.0, 7.512),
    (49, 113) => ("¹¹³In", "indium",     49, 113,  64, 4.601,  112.9040605, 9//2, 1, 1.0e100, 5.5208, 0.761, 4.281),
    (49, 115) => ("¹¹⁵In", "indium",     49, 115,  66, 4.6156, 114.9038788, 9//2, 1, 4.41e14, 5.5326, 0.772, 95.719),
    (50, 112) => ("¹¹²Sn", "tin",        50, 112,  62, 4.5948, 111.9048249, 0, 1, 1.0e100, 0.0, 0.0, 0.97),
    (50, 114) => ("¹¹⁴Sn", "tin",        50, 114,  64, 4.6099, 113.9027801, 0, 1, 1.0e100, 0.0, 0.0, 0.66),
    (50, 115) => ("¹¹⁵Sn", "tin",        50, 115,  65, 4.6148, 114.9033447, 1//2, 1, 1.0e100, -0.9174, 0.0, 0.34),
    (50, 116) => ("¹¹⁶Sn", "tin",        50, 116,  66, 4.625,  115.9017428, 0, 1, 1.0e100, 0.0, 0.0, 14.54),
    (50, 117) => ("¹¹⁷Sn", "tin",        50, 117,  67, 4.6302, 116.9029540, 1//2, 1, 1.0e100, -0.9995, 0.0, 7.68),
    (50, 118) => ("¹¹⁸Sn", "tin",        50, 118,  68, 4.6393, 117.9016066, 0, 1, 1.0e100, 0.0, 0.0, 24.22),
    (50, 119) => ("¹¹⁹Sn", "tin",        50, 119,  69, 4.6438, 118.9033113, 1//2, 1, 1.0e100, -1.0459, 0.0, 8.59),
    (50, 120) => ("¹²⁰Sn", "tin",        50, 120,  70, 4.6519, 119.9022026, 0, 1, 1.0e100, 0.0, 0.0, 32.58),
    (50, 122) => ("¹²²Sn", "tin",        50, 122,  72, 4.6634, 121.9034455, 0, 1, 1.0e100, 0.0, 0.0, 4.63),
    (50, 124) => ("¹²⁴Sn", "tin",        50, 124,  74, 4.6735, 123.9052796, 0, 1, 1.0e100, 0.0, 0.0, 5.79),
    (51, 121) => ("¹²¹Sb", "antimony",   51, 121,  70, 4.6802, 120.9038114, 5//2, 1, 1.0e100, 3.358, -0.543, 57.21),
    (51, 123) => ("¹²³Sb", "antimony",   51, 123,  72, 4.6879, 122.9042153, 7//2, 1, 1.0e100, 2.5457, -0.692, 42.79),
    (52, 120) => ("¹²⁰Te", "tellurium",  52, 120,  68, 4.7038, 119.9040658, 0, 1, 1.0e100, 0.0, 0.0, 0.09),
    (52, 122) => ("¹²²Te", "tellurium",  52, 122,  70, 4.7095, 121.9030447, 0, 1, 1.0e100, 0.0, 0.0, 2.55),
    (52, 123) => ("¹²³Te", "tellurium",  52, 123,  71, 4.7117, 122.9042710, 1//2, 1, 9.2e16, -0.7358, 0.0, 0.89),
    (52, 124) => ("¹²⁴Te", "tellurium",  52, 124,  72, 4.7183, 123.9028183, 0, 1, 1.0e100, 0.0, 0.0, 4.74),
    (52, 125) => ("¹²⁵Te", "tellurium",  52, 125,  73, 4.7204, 124.9044312, 1//2, 1, 1.0e100, -0.887, 0.0, 7.07),
    (52, 126) => ("¹²⁶Te", "tellurium",  52, 126,  74, 4.7266, 125.9033121, 0, 1, 1.0e100, 0.0, 0.0, 8.84),
    (52, 128) => ("¹²⁸Te", "tellurium",  52, 128,  76, 4.7346, 127.9044612, 0, 1, 7.7e24, 0.0, 0.0, 31.74),
    (52, 130) => ("¹³⁰Te", "tellurium",  52, 130,  78, 4.7423, 129.9062227, 0, 1, 7.9e20, 0.0, 0.0, 34.08),
    (53, 127) => ("¹²⁷I" , "iodine",     53, 127,  74, 4.75,   126.9044726, 5//2, 1, 1.0e100, 2.8087, -0.688, 100.0),
    (53, 129) => ("¹²⁹I" , "iodine",     53, 129,  76, 4.8,    128.9049836, 7//2, 1, 1.57e7, 2.6165, -0.483, nothing),
    (54, 124) => ("¹²⁴Xe", "xenon",      54, 124,  70, 4.7661, 123.9058852, 0, 1, 1.6e14, 0.0, 0.0, 0.095),
    (54, 126) => ("¹²⁶Xe", "xenon",      54, 126,  72, 4.7722, 125.9042974, 0, 1, 1.0e100, 0.0, 0.0, 0.089),
    (54, 128) => ("¹²⁸Xe", "xenon",      54, 128,  74, 4.7774, 127.9035308, 0, 1, 1.0e100, 0.0, 0.0, 1.91),
    (54, 129) => ("¹²⁹Xe", "xenon",      54, 129,  75, 4.7775, 128.9047809, 1//2, 1, 1.0e100, -0.777961, 0.0, 26.401),
    (54, 130) => ("¹³⁰Xe", "xenon",      54, 130,  76, 4.7818, 129.9035093, 0, 1, 1.0e100, 0.0, 0.0, 4.071),
    (54, 131) => ("¹³¹Xe", "xenon",      54, 131,  77, 4.7808, 130.9050841, 3//2, 1, 1.0e100, 0.691845, -0.114, 21.232),
    (54, 132) => ("¹³²Xe", "xenon",      54, 132,  78, 4.7859, 131.9041551, 0, 1, 1.0e100, 0.0, 0.0, 26.909),
    (54, 134) => ("¹³⁴Xe", "xenon",      54, 134,  80, 4.7899, 133.9053930, 0, 1, 5.8e22, 0.0, 0.0, 10.436),
    (54, 136) => ("¹³⁶Xe", "xenon",      54, 136,  82, 4.7964, 135.9072145, 0, 1, 2.17e21, 0.0, 0.0, 8.857),
    (55, 133) => ("¹³³Cs", "caesium",    55, 133,  78, 4.8041, 132.9054520, 7//2, 1, 1.0e100, 2.5778, -0.00343, 100.0),
    (55, 134) => ("¹³⁴Cs", "caesium",    55, 134,  79, 4.805,  133.9286804, 4, 1, 2.06, 2.9893, 0.37, nothing),
    (55, 135) => ("¹³⁵Cs", "caesium",    55, 135,  80, 4.8067, 134.9059769, 7//2, 1, 2.3e6, 2.7283, 0.048, nothing),
    (55, 137) => ("¹³⁷Cs", "caesium",    55, 137,  82, 4.807,  136.9461620, 7//2, 1, 30.1, 2.8374, 0.048, nothing),
    (56, 130) => ("¹³⁰Ba", "barium",     56, 130,  74, 4.8283, 129.9063260, 0, 1, 1.0e100, 0.0, 0.0, 0.11),
    (56, 132) => ("¹³²Ba", "barium",     56, 132,  76, 4.8303, 131.9050612, 0, 1, 3.0e21, 0.0, 0.0, 0.1),
    (56, 134) => ("¹³⁴Ba", "barium",     56, 134,  78, 4.8322, 133.9045082, 0, 1, 1.0e100, 0.0, 0.0, 2.42),
    (56, 135) => ("¹³⁵Ba", "barium",     56, 135,  79, 4.8294, 134.9056884, 3//2, 1, 1.0e100, 0.8381, 0.153, 6.59),
    (56, 136) => ("¹³⁶Ba", "barium",     56, 136,  80, 4.8334, 135.9045758, 0, 1, 1.0e100, 0.0, 0.0, 7.85),
    (56, 137) => ("¹³⁷Ba", "barium",     56, 137,  81, 4.8314, 136.9058272, 3//2, 1, 1.0e100, 0.9375, 0.236, 11.23),
    (56, 138) => ("¹³⁸Ba", "barium",     56, 138,  82, 4.8378, 137.9052471, 0, 1, 1.0e100, 0.0, 0.0, 71.7),
    (57, 137) => ("¹³⁷La", "lanthanum",  57, 137,  80, 4.8496, 136.9064504, 7//2, 1, 60000.0, 2.696, 0.21, nothing),
    (57, 138) => ("¹³⁸La", "lanthanum",  57, 138,  81, 4.8473, 137.9071240, 5, 1, 1.03e11, 3.7084, 0.39, 0.08881),
    (57, 139) => ("¹³⁹La", "lanthanum",  57, 139,  82, 4.855,  138.9063629, 7//2, 1, 1.0e100, 2.7791, 0.206, 99.91119),
    (58, 136) => ("¹³⁶Ce", "cerium",     58, 136,  78, 4.8739, 135.9071293, 0, 1, 1.0e100, 0.0, 0.0, 0.186),
    (58, 138) => ("¹³⁸Ce", "cerium",     58, 138,  80, 4.8737, 137.9059942, 0, 1, 4.4e16, 0.0, 0.0, 0.251),
    (58, 140) => ("¹⁴⁰Ce", "cerium",     58, 140,  82, 4.8771, 139.9054484, 0, 1, 1.0e100, 0.0, 0.0, 88.449),
    (58, 142) => ("¹⁴²Ce", "cerium",     58, 142,  84, 4.9063, 141.9092502, 0, 1, 5.0e16, 0.0, 0.0, 11.114),
    (59, 141) => ("¹⁴¹Pr", "praseodymium",59,141,  82, 4.8919, 140.9076596, 5//2, 1, 1.0e100, 4.266, -0.077, 100.0),
    (60, 142) => ("¹⁴²Nd", "neodymium",  60, 142,  82, 4.9123, 141.9077288, 0, 1, 1.0e100, 0.0, 0.0, 27.153),
    (60, 143) => ("¹⁴³Nd", "neodymium",  60, 143,  83, 4.9254, 142.9098198, 7//2, -1, 1.0e100, -1.065, -0.61, 12.173),
    (60, 144) => ("¹⁴⁴Nd", "neodymium",  60, 144,  84, 4.9421, 143.9100928, 0, 1, 2.29e15, 0.0, 0.0, 23.798),
    (60, 145) => ("¹⁴⁵Nd", "neodymium",  60, 145,  85, 4.9535, 144.9125792, 7//2, -1, 1.0e100, -0.656, -0.314, 8.293),
    (60, 146) => ("¹⁴⁶Nd", "neodymium",  60, 146,  86, 4.9696, 145.9131225, 0, 1, 1.0e100, 0.0, 0.0, 17.189),
    (60, 148) => ("¹⁴⁸Nd", "neodymium",  60, 148,  88, 4.9999, 147.9168990, 0, 1, 1.0e100, 0.0, 0.0, 5.756),
    (60, 150) => ("¹⁵⁰Nd", "neodymium",  60, 150,  90, 5.04,   149.9209013, 0, 1, 9.1e18, 0.0, 0.0, 5.638),
    (61, 147) => ("¹⁴⁷Pm", "promethium", 61, 147,  86, 5.0,    146.9151449, 7//2, 1, 2.623, 2.58, 0.74, nothing),
    (62, 144) => ("¹⁴⁴Sm", "samarium",   62, 144,  82, 4.9524, 143.9120063, 0, 1, 1.0e100, 0.0, 0.0, 3.08),
    (62, 146) => ("¹⁴⁶Sm", "samarium",   62, 146,  84, 4.9808, 145.9130468, 0, 1, 6.8e7, 0.0, 0.0, nothing),
    (62, 147) => ("¹⁴⁷Sm", "samarium",   62, 147,  85, 4.9892, 146.9149044, 7//2, -1, 1.07e11, -0.809, -0.26, 15.0),
    (62, 148) => ("¹⁴⁸Sm", "samarium",   62, 148,  86, 5.0042, 147.9148292, 0, 1, 7.0e15, 0.0, 0.0, 11.25),
    (62, 149) => ("¹⁴⁹Sm", "samarium",   62, 149,  87, 5.0134, 148.9171912, 7//2, -1, 1.0e100, -0.6677, 0.078, 13.82),
    (62, 150) => ("¹⁵⁰Sm", "samarium",   62, 150,  88, 5.0387, 149.9172820, 0, 1, 1.0e100, 0.0, 0.0, 7.37),
    (62, 151) => ("¹⁵¹Sm", "samarium",   62, 151,  89, 5.055,  150.9199389, 5//2, -1, 90.0, -0.3605, 0.71, 0.0057),
    (62, 152) => ("¹⁵²Sm", "samarium",   62, 152,  90, 5.0819, 151.9197386, 0, 1, 1.0e100, 0.0, 0.0, 26.74),
    (62, 154) => ("¹⁵⁴Sm", "samarium",   62, 154,  92, 5.1053, 153.9222158, 0, 1, 1.0e100, 0.0, 0.0, 22.74),
    (63, 150) => ("¹⁵⁰Eu", "europium",   63, 150,  87, 5.0296, 149.9197071, 5, -1, 36.9, 2.702, 1.13, 0.0108),
    (63, 151) => ("¹⁵¹Eu", "europium",   63, 151,  88, 5.0522, 150.9198566, 5//2, 1, 1.7e18, 3.4635, 0.903, 47.81),
    (63, 153) => ("¹⁵³Eu", "europium",   63, 153,  90, 5.1115, 152.9212368, 5//2, 1, 1.0e100, 1.5294, 2.41, 0.0062),
    (63, 154) => ("¹⁵⁴Eu", "europium",   63, 154,  91, 5.1239, 153.9229857, 3, -1, 8.601, -2.0, 2.85, 0.0079),
    (63, 155) => ("¹⁵⁵Eu", "europium",   63, 155,  92, 5.1221, 154.9228998, 5//2, 1, 4.753, 1.516, 2.5, 0.0069),
    (64, 152) => ("¹⁵²Gd", "gadolinium", 64, 152,  88, 5.0774, 151.9197984, 0, 1, 1.08e14, 0.0, 0.0, 0.2),
    (64, 154) => ("¹⁵⁴Gd", "gadolinium", 64, 154,  90, 5.1223, 153.9208730, 0, 1, 1.0e100, 0.0, 0.0, 2.18),
    (64, 155) => ("¹⁵⁵Gd", "gadolinium", 64, 155,  91, 5.1319, 154.9226294, 3//2, -1, 1.0e100, -0.2591, 1.27, 14.8),
    (64, 156) => ("¹⁵⁶Gd", "gadolinium", 64, 156,  92, 5.142,  155.9221301, 0, 1, 1.0e100, 0.0, 0.0, 20.47),
    (64, 157) => ("¹⁵⁷Gd", "gadolinium", 64, 157,  93, 5.1449, 156.9239674, 3//2, -1, 1.0e100, -0.3398, 1.36, 15.65),
    (64, 158) => ("¹⁵⁸Gd", "gadolinium", 64, 158,  94, 5.1569, 157.9241112, 0, 1, 1.0e100, 0.0, 0.0, 24.84),
    (64, 160) => ("¹⁶⁰Gd", "gadolinium", 64, 160,  96, 5.1734, 159.9270612, 0, 1, 1.0e100, 0.0, 0.0, 21.86),
    (65, 157) => ("¹⁵⁷Tb", "terbium",    65, 157,  92, 5.0489, 156.9240319, 3//2, 1, 71.0, 2.03, 1.4, 0.15),
    (65, 159) => ("¹⁵⁹Tb", "terbium",    65, 159,  94, 5.06,   158.9253537, 3//2, 1, 1.0e100, 2.009, 1.432, 100.0),
    (66, 156) => ("¹⁵⁶Dy", "dysprosium", 66, 156,  90, 5.1622, 155.9242836, 0, 1, 1.0e100, 0.0, 0.0, 0.056),
    (66, 158) => ("¹⁵⁸Dy", "dysprosium", 66, 158,  92, 5.1815, 157.9244148, 0, 1, 1.0e100, 0.0, 0.0, 0.095),
    (66, 160) => ("¹⁶⁰Dy", "dysprosium", 66, 160,  94, 5.1951, 159.9252036, 0, 1, 1.0e100, 0.0, 0.0, 2.329),
    (66, 161) => ("¹⁶¹Dy", "dysprosium", 66, 161,  95, 5.1962, 160.9269394, 5//2, 1, 1.0e100, -0.479, 2.51, 18.889),
    (66, 162) => ("¹⁶²Dy", "dysprosium", 66, 162,  96, 5.2074, 161.9268045, 0, 1, 1.0e100, 0.0, 0.0, 25.475),
    (66, 163) => ("¹⁶³Dy", "dysprosium", 66, 163,  97, 5.2099, 162.9287372, 5//2, -1, 1.0e100, 0.671, 2.65, 24.896),
    (66, 164) => ("¹⁶⁴Dy", "dysprosium", 66, 164,  98, 5.2218, 163.9291808, 0, 1, 1.0e100, 0.0, 0.0, 28.26),
    (67, 163) => ("¹⁶³Ho", "holmium",    67, 163,  96, 5.1907, 162.9287403, 7//2, -1, 4570.0, 4.22, 3.7, nothing),
    (67, 165) => ("¹⁶⁵Ho", "holmium",    67, 165,  98, 5.2022, 164.9303291, 7//2, -1, 1.0e100, 4.16, 3.58, 100.0),
    (68, 162) => ("¹⁶²Er", "erbium",     68, 162,  94, 5.2246, 161.9287873, 0, 1, 1.0e100, 0.0, 0.0, 0.139),
    (68, 164) => ("¹⁶⁴Er", "erbium",     68, 164,  96, 5.2389, 163.9292077, 0, 1, 1.0e100, 0.0, 0.0, 1.601),
    (68, 166) => ("¹⁶⁶Er", "erbium",     68, 166,  98, 5.2516, 165.9303011, 0, 1, 1.0e100, 0.0, 0.0, 33.503),
    (68, 167) => ("¹⁶⁷Er", "erbium",     68, 167,  99, 5.256,  166.9320562, 7//2, 1, 1.0e100, -0.5623, 3.57, 22.869),
    (68, 168) => ("¹⁶⁸Er", "erbium",     68, 168, 100, 5.2644, 167.9323783, 0, 1, 1.0e100, 0.0, 0.0, 26.978),
    (68, 170) => ("¹⁷⁰Er", "erbium",     68, 170, 102, 5.2789, 169.9354719, 0, 1, 1.0e100, 0.0, 0.0, 14.91),
    (69, 169) => ("¹⁶⁹Tm", "thulium",    69, 169, 100, 5.2256, 168.9342190, 1//2, 1, 1.0e100, -0.231, 0.0, 100.0),
    (69, 171) => ("¹⁷¹Tm", "thulium",    69, 171, 102, 5.2388, 170.9364352, 1//2, 1, 1.92, -0.23, 0.0, nothing),
    (70, 168) => ("¹⁶⁸Yb", "ytterbium",  70, 168, 98, 5.2702,  167.9338913, 0, 1, 1.0e100, 0.0, 0.0, 0.123),
    (70, 170) => ("¹⁷⁰Yb", "ytterbium",  70, 170, 100, 5.2853, 169.9347672, 0, 1, 1.0e100, 0.0, 0.0, 2.982),
    (70, 171) => ("¹⁷¹Yb", "ytterbium",  70, 171, 101, 5.2906, 170.9363315, 1//2, -1, 1.0e100, 0.4923, 0.0, 14.086),
    (70, 172) => ("¹⁷²Yb", "ytterbium",  70, 172, 102, 5.2995, 171.9363867, 0, 1, 1.0e100, 0.0, 0.0, 21.686),
    (70, 173) => ("¹⁷³Yb", "ytterbium",  70, 173, 103, 5.3046, 172.9382162, 5//2, -1, 1.0e100, -0.678, 2.8, 16.103),
    (70, 174) => ("¹⁷⁴Yb", "ytterbium",  70, 174, 104, 5.3108, 173.9388675, 0, 1, 1.0e100, 0.0, 0.0, 32.025),
    (70, 176) => ("¹⁷⁶Yb", "ytterbium",  70, 176, 106, 5.3215, 175.9425747, 0, 1, 1.0e100, 0.0, 0.0, 12.995),
    (71, 173) => ("¹⁷³Lu", "lutetium",   71, 173, 102, 5.3577, 172.9389357, 7//2, 1, 1.37, 2.273, 3.53, nothing),
    (71, 174) => ("¹⁷⁴Lu", "lutetium",   71, 174, 103, 5.3634, 173.9403428, 1, -1, 3.31, 1.982, 0.773, nothing),
    (71, 175) => ("¹⁷⁵Lu", "lutetium",   71, 175, 104, 5.37,   174.9407772, 7//2, 1, 1.0e100, 2.2257, 3.49, 97.401),
    (71, 176) => ("¹⁷⁶Lu", "lutetium",   71, 176, 105, 5.3739, 175.9426917, 7, -1, 3.76e10, 3.16, 4.92, 2.599),
    (72, 174) => ("¹⁷⁴Hf", "hafnium",    72, 174, 102, 5.3201, 173.9400484, 0, 1, 2.0e15, 0.0, 0.0, 0.16),
    (72, 176) => ("¹⁷⁶Hf", "hafnium",    72, 176, 104, 5.3286, 175.9414098, 0, 1, 1.0e100, 0.0, 0.0, 5.26),
    (72, 177) => ("¹⁷⁷Hf", "hafnium",    72, 177, 105, 5.3309, 176.9432302, 7//2, -1, 1.0e100, 0.791, 3.37, 18.6),
    (72, 178) => ("¹⁷⁸Hf", "hafnium",    72, 178, 106, 5.3371, 177.9437083, 0, 1, 1.0e100, 0.0, 0.0, 27.28),
    (72, 179) => ("¹⁷⁹Hf", "hafnium",    72, 179, 107, 5.3408, 178.9458257, 9//2, 1, 1.0e100, -0.6389, 3.79, 13.62),
    (72, 180) => ("¹⁸⁰Hf", "hafnium",    72, 180, 108, 5.347,  179.9465595, 0, 1, 1.0e100, 0.0, 0.0, 35.08),
    (72, 182) => ("¹⁸²Hf", "hafnium",    72, 182, 110, 5.3516, 181.9505637, 0, 1, 8.9e6, 0.0, 0.0, nothing),
    (73, 179) => ("¹⁷⁹Ta", "tantalum",   73, 179, 106, 5.3,    178.9459391, 7//2, 1, 1.82, 2.286, 3.27, nothing),
    (73, 181) => ("¹⁸¹Ta", "tantalum",   73, 181, 108, 5.3507, 180.9479985, 7//2, 1, 1.0e100, 2.365, 3.17, 99.98799),
    (74, 180) => ("¹⁸⁰W" , "tungsten",   74, 180, 106, 5.3491, 179.9467133, 0, 1, 1.8e18, 0.0, 0.0, 0.12),
    (74, 182) => ("¹⁸²W" , "tungsten",   74, 182, 108, 5.3559, 181.9482056, 0, 1, 1.0e100, 0.0, 0.0, 26.5),
    (74, 183) => ("¹⁸³W" , "tungsten",   74, 183, 109, 5.3611, 182.9502244, 1//2, -1, 6.7e20, 0.11739, 0.0, 14.31),
    (74, 184) => ("¹⁸⁴W" , "tungsten",   74, 184, 110, 5.3658, 183.9509332, 0, 1, 1.0e100, 0.0, 0.0, 30.64),
    (74, 186) => ("¹⁸⁶W" , "tungsten",   74, 186, 112, 5.3743, 185.9543651, 0, 1, 1.0e100, 0.0, 0.0, 28.43),
    (75, 185) => ("¹⁸⁵Re", "rhenium",    75, 185, 110, 5.3596, 184.9529583, 5//2, 1, 1.0e100, 3.176, 2.07, 37.4),
    (75, 187) => ("¹⁸⁷Re", "rhenium",    75, 187, 112, 5.3698, 186.9557522, 5//2, 1, 4.33e10, 3.209, 1.94, 62.6),
    (76, 184) => ("¹⁸⁴Os", "osmium",     76, 184, 108, 5.3823, 183.9524929, 0, 1, 5.6e13, 0.0, 0.0, 0.02),
    (76, 186) => ("¹⁸⁶Os", "osmium",     76, 186, 110, 5.3909, 185.9538376, 0, 1, 2.0e15, 0.0, 0.0, 1.59),
    (76, 187) => ("¹⁸⁷Os", "osmium",     76, 187, 111, 5.3933, 186.9557496, 1//2, -1, 1.0e100, 0.06442, 0.0, 1.96),
    (76, 188) => ("¹⁸⁸Os", "osmium",     76, 188, 112, 5.3993, 187.9558373, 0, 1, 1.0e100, 0.0, 0.0, 13.24),
    (76, 189) => ("¹⁸⁹Os", "osmium",     76, 189, 113, 5.4016, 188.9581459, 3//2, -1, 1.0e100, 0.6576, 0.86, 16.15),
    (76, 190) => ("¹⁹⁰Os", "osmium",     76, 190, 114, 5.4062, 189.9584454, 0, 1, 1.0e100, 0.0, 0.0, 26.26),
    (76, 192) => ("¹⁹²Os", "osmium",     76, 192, 116, 5.4126, 191.9614788, 0, 1, 1.0e100, 0.0, 0.0, 40.78),
    (77, 191) => ("¹⁹¹Ir", "iridium",    77, 191, 114, 5.3968, 190.9605915, 3//2, 1, 1.0e100, 0.1502, 0.8, 37.3),
    (77, 193) => ("¹⁹³Ir", "iridium",    77, 193, 116, 5.4032, 192.9629238, 3//2, 1, 1.0e100, 0.163, 0.7, 62.7),
    (78, 190) => ("¹⁹⁰Pt", "platinum",   78, 190, 112, 5.4108, 189.9599498, 0, 1, 4.97e11, 0.0, 0.0, 0.012),
    (78, 192) => ("¹⁹²Pt", "platinum",   78, 192, 114, 5.4169, 191.9610427, 0, 1, 1.0e100, 0.0, 0.0, 0.782),
    (78, 193) => ("¹⁹³Pt", "platinum",   78, 193, 115, 5.4191, 192.9629845, 1//2, -1, 50.0, 0.601, 0.0, nothing),
    (78, 194) => ("¹⁹⁴Pt", "platinum",   78, 194, 116, 5.4236, 193.9626835, 0, 1, 1.0e100, 0.0, 0.0, 32.864),
    (78, 195) => ("¹⁹⁵Pt", "platinum",   78, 195, 117, 5.427,  194.9647943, 1//2, -1, 1.0e100, 0.6073, 0.0, 33.775),
    (78, 196) => ("¹⁹⁶Pt", "platinum",   78, 196, 118, 5.4307, 195.9649546, 0, 1, 1.0e100, 0.0, 0.0, 25.211),
    (78, 198) => ("¹⁹⁸Pt", "platinum",   78, 198, 120, 5.4383, 197.9678967, 0, 1, 1.0e100, 0.0, 0.0, 7.356),
    (79, 197) => ("¹⁹⁷Au", "gold",       79, 197, 118, 5.4371, 196.9665701, 3//2, 1, 1.0e100, 0.1452, 0.547, 100.0),
    (80, 196) => ("¹⁹⁶Hg", "mercury",    80, 196, 116, 5.4385, 195.9658334, 0, 1, 1.0e100, 0.0, 0.0, 0.15),
    (80, 198) => ("¹⁹⁸Hg", "mercury",    80, 198, 118, 5.4463, 197.9667692, 0, 1, 1.0e100, 0.0, 0.0, 10.04),
    (80, 199) => ("¹⁹⁹Hg", "mercury",    80, 199, 119, 5.4474, 198.9682810, 1//2, -1, 1.0e100, 0.5039, 0.0, 16.94),
    (80, 200) => ("²⁰⁰Hg", "mercury",    80, 200, 120, 5.4551, 199.9683269, 0, 1, 1.0e100, 0.0, 0.0, 23.14),
    (80, 201) => ("²⁰¹Hg", "mercury",    80, 201, 121, 5.4581, 200.9703031, 3//2, -1, 1.0e100, -0.558, 0.387, 13.17),
    (80, 202) => ("²⁰²Hg", "mercury",    80, 202, 122, 5.4648, 201.9706436, 0, 1, 1.0e100, 0.0, 0.0, 9.74),
    (80, 204) => ("²⁰⁴Hg", "mercury",    80, 204, 124, 5.4744, 203.9734940, 0, 1, 1.0e100, 0.0, 0.0, 6.82),
    (81, 203) => ("²⁰³Tl", "thallium",   81, 203, 122, 5.4666, 202.9723441, 1//2, 1, 1.0e100, 1.616, 0.0, 29.515),
    (81, 205) => ("²⁰⁵Tl", "thallium",   81, 205, 124, 5.4759, 204.9744273, 1//2, 1, 1.0e100, 1.632, 0.0, 70.485),
    (82, 202) => ("²⁰²Pb", "lead",       82, 202, 120, 5.4705, 201.9721516, 0, 1, 52500.0, 0.0, 0.0, nothing),
    (82, 204) => ("²⁰⁴Pb", "lead",       82, 204, 122, 5.4803, 203.9730435, 0, 1, 1.4e17, 0.0, 0.0, 1.4),
    (82, 205) => ("²⁰⁵Pb", "lead",       82, 205, 123, 5.4828, 204.9744817, 5//2, -1, 1.7e7, 0.7094, 0.23, nothing),
    (82, 206) => ("²⁰⁶Pb", "lead",       82, 206, 124, 5.4902, 205.9744652, 0, 1, 1.0e100, 0.0, 0.0, 24.1),
    (82, 207) => ("²⁰⁷Pb", "lead",       82, 207, 125, 5.4943, 206.9758968, 1//2, -1, 1.0e100, 0.5906, 0.0, 22.1),
    (82, 208) => ("²⁰⁸Pb", "lead",       82, 208, 126, 5.5012, 207.976652, 0, 1, 1.0e100, 0.0, 0.0, 52.4),
    (83, 207) => ("²⁰⁷Bi", "bismuth",    83, 207, 124, 5.5103, 206.9784706, 9//2, -1, 31.55, 4.0729, -0.76, nothing),
    (83, 208) => ("²⁰⁸Bi", "bismuth",    83, 208, 125, 5.5147, 207.9797421, 5, 1, 368000.0, 4.572, -0.7, nothing),
    (83, 209) => ("²⁰⁹Bi", "bismuth",    83, 209, 126, 5.5211, 208.9803986, 9//2, -1, 2.01e19, 4.092, -0.516, 100.0),
    (84, 209) => ("²⁰⁹Po", "polonium",   84, 209, 125, 5.5628, 208.9824304, 1//2, -1, 124.0, 0.68, 0.0, nothing),
    (89, 227) => ("²²⁷Ac", "actinium",   89, 227, 138, 5.6,    227.0277506, 3//2, -1, 21.772, 1.1, 1.74, nothing),
    (90, 229) => ("²²⁹Th", "thorium",    90, 229, 139, 5.7557, 229.0317614, 5//2, 1, 7880.0, 0.46, 3.11, nothing),
    (90, 230) => ("²³⁰Th", "thorium",    90, 230, 140, 5.767,  230.0331323, 0, 1, 75400.0, 0.0, 0.0, 0.02),
    (90, 232) => ("²³²Th", "thorium",    90, 232, 142, 5.7848, 232.0380536, 0, 1, 1.4e10, 0.0, 0.0, 99.98),
    (91, 231) => ("²³¹Pa", "protactinium", 91, 231, 140, 5.8,  231.0358825, 3//2, -1, 32800.0, 1.99, -1.72, 100.0),
    (92, 233) => ("²³³U" , "uranium",    92, 233, 141, 5.8203, 233.0396343, 5//2, 1, 159000.0, -0.59, 3.663, nothing),
    (92, 234) => ("²³⁴U" , "uranium*",   92, 234, 142, 5.8291, 234.0409503, 0, 1, 246000.0, 0.0, 0.0, 0.0054),
    (92, 235) => ("²³⁵U" , "uranium",    92, 235, 143, 5.8337, 235.0439281, 7//2, -1, 7.04e8, -0.38, 4.936, 0.7204),
    (92, 236) => ("²³⁶U" , "uranium",    92, 236, 144, 5.8431, 236.0455661, 0, 1, 2.34e7, 0.0, 0.0, nothing),
    (92, 238) => ("²³⁸U" , "uranium",    92, 238, 146, 5.8571, 238.0507869, 0, 1, 4.47e9, 0.0, 0.0, 99.2742),
    (93, 237) => ("²³⁷Np", "neptunium",  93, 237, 144, 5.85,   237.0481716, 5//2, 1, 2.14e6, 3.16, 3.886, nothing),
    (94, 239) => ("²³⁹Pu", "plutonium",  94, 239, 145, 5.8601, 239.0521616, 1//2, 1, 24110.0, 0.202, 0.0, nothing),
    (94, 240) => ("²⁴⁰Pu", "plutonium",  94, 240, 146, 5.8701, 240.0538117, 0, 1, 6561.0, 0.0, 0.0, nothing),
    (94, 241) => ("²⁴¹Pu", "plutonium",  94, 241, 147, 5.8748, 241.0568497, 5//2, 1, 14.329, -0.678, 6.0, nothing),
    (94, 242) => ("²⁴²Pu", "plutonium",  94, 242, 148, 5.8823, 242.0587410, 0, 1, 375000.0, 0.0, 0.0, nothing),
    (94, 244) => ("²⁴⁴Pu", "plutonium",  94, 244, 150, 5.8948, 244.0642044, 0, 1, 8.13e7, 0.0, 0.0, nothing),
    (95, 241) => ("²⁴¹Am", "americium",  95, 241, 146, 5.8928, 241.0568273, 5//2, -1, 432.6, 1.6, 4.34, nothing),
    (95, 243) => ("²⁴³Am", "americium",  95, 243, 148, 5.9048, 243.0613799, 5//2, -1, 7364.0, 1.52, 4.32, nothing)

    )
